package edu.georgetown.gucs.dictionary;

/**
 * Prints statistics for a {@linkplain Dictionary}:
 * <ul>
 * <li>Name</li>
 * <li>Language</li>
 * <li>Number of documents</li>
 * <li>Number of tokens</li>
 * <li>If the dictionary has been trimmed (including the IDF range, if trimmed)</li>
 * <li>Minimum and maximum IDF</li>
 * <li>List of tokenizers</li>
 * </ul>
 * 
 * @author Clay Shields
 * 
 */
public class ShowDictionaryStatistics {

  private Dictionary dictionary;

  /**
   * Constructor that specifies the dictionary and its language
   * 
   * @param dictionary_file
   *          the string filename containing the serialized dictionary
   */
  public ShowDictionaryStatistics(String dictionary_file) {
    dictionary = new Dictionary(dictionary_file);
    dictionary.showStatistics();
  }

  /**
   * Prints statistics for a dictionary, including name, language, number of documents, number of tokens, minimum and
   * maximum IDF, list of tokenizers, and whether the dictionary has been trimmed
   * 
   * @param args
   *          array of string command line arguments<br>
   *          <code>args[0]</code> the filename containing the dictionary to show
   */
  public static void main(String args[]) {

    String dictionary_file = null;

    try {
      dictionary_file = args[0];
    } catch (ArrayIndexOutOfBoundsException e) {
      System.err.println("Usage: java ShowDictionaryStatstics <dictionary file name>");
      System.err.println("Prints statistics for a dictionary, including name, language, number of "
          + "documents, number of tokens, minimum and maximum IDF, list of tokenizers, and whether "
          + "the dictionary has been trimmed");
      System.exit(-1);
    }

    new ShowDictionaryStatistics(dictionary_file);
  }
}
