package edu.georgetown.gucs.matcher;

import java.util.Arrays;

import edu.georgetown.gucs.fingerprinter.BitVectorFingerprinter;

/**
 * Determines if two fingerprints' documents are the same; uses a {@linkplain BitVectorFingerprinter}
 * 
 * @author Clay Shields
 */
public class ExactFingerprintMatcher extends FingerprintMatcher {

  /**
   * Constructor that sets the minimum score to use for matching two fingerprints to zero
   **/
  public ExactFingerprintMatcher() {
    super();
  }

  /**
   * Determines that the two fingerprints are matching if their byte arrays are equal
   */
  public boolean match(byte[] fp1, byte[] fp2) {
    return Arrays.equals(fp1, fp2);
  }

  /**
   * Determines a similarity score for these two fingerprints
   * 
   * @return the similarity score between these two fingerprints; returns 0 if the fingerprints are not an exact match,
   *         returns 99 they are
   */
  public int getScore(byte[] fp1, byte[] fp2) {
    if (match(fp1, fp2))
      return 99;
    return 0;
  }

  public static void main(String[] args) {
    String dictionary = null;
    String file1 = null;
    String file2 = null;

    try {
      dictionary = args[0];
      file1 = args[1];
      file2 = args[2];
    } catch (ArrayIndexOutOfBoundsException e) {
      System.err.println("Usage: java ExactFingerprintMatcher <dictionary> <fingeprint file> <fingeprint file>");
      System.exit(-1);
    }

    // Create two fingerprinters
    BitVectorFingerprinter fpr = new BitVectorFingerprinter(dictionary);
    String fp1 = fpr.computeFingerprintXML(file1);
    String fp2 = fpr.computeFingerprintXML(file2);
    ExactFingerprintMatcher efpm = new ExactFingerprintMatcher();

    if (efpm.match(fp1, fp2)) {
      System.out.println("MATCH");
    } else {
      System.out.println("NOT A MATCH");
    }
  }
}
