package edu.georgetown.gucs.tokenizers;

import java.util.Iterator;
import java.util.StringTokenizer;

import edu.georgetown.gucs.utility.Pair;

/**
 * Eliminates tokens related to attachments in the Enron data set
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class EnronEmailTokenizer extends Tokenizer {

  /**
   * Eliminates tokens related to attachments in the Enron data set
   */
  public void tokenize(Iterator<String> iterator) {
    tokenVector.clear();
    while (iterator.hasNext()) {
      String token = iterator.next();
      if (token.contains("Content-Disposition: attachment;")) {
        break;
      } else {
        StringTokenizer st = new StringTokenizer(token);
        while (st.hasMoreTokens()) {
          String newToken = st.nextToken().trim();
          tokenVector.add(newToken);
        }
      }
    }
  }

  /**
   * Eliminates tokens related to attachments in the Enron data set
   */
  public void tokenize(Iterator<String> tokensIterator, Iterator<Pair<Integer, Integer>> positionsIterator) {
    tokenVector.clear();
    positions.clear();
    while (tokensIterator.hasNext() && positionsIterator.hasNext()) {
      String token = tokensIterator.next();
      Pair<Integer, Integer> pos = positionsIterator.next();
      if (token.contains("Content-Disposition: attachment;")) {
        break;
      } else {
        StringTokenizer st = new StringTokenizer(token);
        while (st.hasMoreTokens()) {
          String newToken = st.nextToken().trim();
          tokenVector.add(newToken);
          positions.add(pos);
        }
      }
    }
  }
}
