package edu.georgetown.gucs.tokenizers;

import java.util.Iterator;
import java.util.StringTokenizer;

import edu.georgetown.gucs.utility.Pair;

/**
 * Eliminates tokens from headers in the Enron data set
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class EnronStripMailHeaderTokenizer extends Tokenizer {

  private boolean started;

  /**
   * Constructor to remove tokens from headers in the Enron data set
   */
  public EnronStripMailHeaderTokenizer() {
    started = false;
  }

  /**
   * Eliminates tokens from headers in the Enron data set
   */
  public void tokenize(Iterator<String> iterator) {
    tokenVector.clear();
    while (iterator.hasNext()) {
      String token = iterator.next();
      if (token.contains("X-FileName")) {
        started = true;
      }
      if (started) {
        if (!token.contains("X-FileName")) {
          StringTokenizer st = new StringTokenizer(token);
          while (st.hasMoreTokens()) {
            String newToken = st.nextToken();
            tokenVector.add(newToken);
          }
        }
      }
    }
  }

  /**
   * Eliminates tokens from headers in the Enron data set
   */
  public void tokenize(Iterator<String> tokensIterator, Iterator<Pair<Integer, Integer>> positionsIterator) {
    tokenVector.clear();
    positions.clear();
    while (tokensIterator.hasNext() && positionsIterator.hasNext()) {
      String token = tokensIterator.next();
      Pair<Integer, Integer> pos = positionsIterator.next();
      if (token.contains("X-FileName")) {
        started = true;
      }
      if (started) {
        if (!token.contains("X-FileName")) {
          StringTokenizer st = new StringTokenizer(token);
          while (st.hasMoreTokens()) {
            String newToken = st.nextToken().trim();
            tokenVector.add(newToken);
            positions.add(pos);
          }
        }
      }
    }
  }
}
