package edu.georgetown.gucs.tokenizers;

import java.util.Iterator;

import edu.georgetown.gucs.utility.Pair;

/**
 * Eliminates tokens that are shorter than a given length
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class MinimumLengthTokenizer extends Tokenizer {

  private int minTokenLength;

  /**
   * Constructor that sets the minimum token length to be considered
   * 
   * @param length
   *          the string value of the minimum token length to be included
   */
  public MinimumLengthTokenizer(String length) {
    minTokenLength = Integer.parseInt(length);
  }

  /**
   * Eliminates tokens that are shorter than the length specified in the constructor
   */
  public void tokenize(Iterator<String> iterator) {
    tokenVector.clear();
    while (iterator.hasNext()) {
      String token = iterator.next().trim();
      if (token.length() >= minTokenLength) {
        tokenVector.add(token);
      }
    }
  }

  /**
   * Eliminates tokens that are shorter than the length specified in the constructor
   */
  public void tokenize(Iterator<String> tokensIterator, Iterator<Pair<Integer, Integer>> positionsIterator) {
    tokenVector.clear();
    positions.clear();
    while (tokensIterator.hasNext() && positionsIterator.hasNext()) {
      String token = tokensIterator.next().trim();
      Pair<Integer, Integer> pos = positionsIterator.next();
      if (token.length() >= minTokenLength) {
        tokenVector.add(token);
        positions.add(pos);
      }
    }
  }
}
