package edu.georgetown.gucs.utility;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * Prints exception messages and stack traces before calling <code>System.exit(-1)</code>
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class ExceptionHandler {

  /**
   * Prints the message and stack trace for this Exception
   * 
   * @param exception
   *          the exception that provides information on error
   */
  public static void handleException(Exception exception) {
    System.err.println(exception.getMessage());
    exception.printStackTrace();
    throw new RuntimeException(exception);
  }

  /**
   * Prints the message and stack trace for this InternalError
   * 
   * @param error
   *          the internal error that provides information
   */
  public static void handleException(InternalError error) {
    System.err.println(error.getMessage());
    error.printStackTrace();
    throw new RuntimeException(error);
  }

  /**
   * Prints the message, SQLState, vendor-specific exception code, and stack trace for this SQLException
   * 
   * @param exception
   *          the sqlException that provides information on the database access error or other errors
   */
  public static void handleSQLException(SQLException exception) {
    SQLException except = exception;
    do {
      System.err.println();
      System.err.println("SQL Exception:");
      System.err.println(exception.getMessage());
      System.err.println("ANSI-92 SQL State: " + exception.getSQLState());
      System.err.println("Vendor Error Code: " + exception.getErrorCode());
      exception.printStackTrace();
      exception = exception.getNextException();
    } while (exception != null);
    throw new RuntimeException(except);
  }

  /**
   * Prints the message, SQLState, vendor-specific exception code, and stack trace for this SQLException
   * 
   * @param exception
   *          the sqlException that provides information on the database access error or other errors
   * @param database
   *          the connection for the database that caused this exception
   * @param statement
   *          the SQL statement that caused this exception
   */
  public static void handleSQLException(SQLException exception, Connection database, Statement statement) {
    SQLException except = exception;
    do {
      System.err.println();
      System.err.println("SQL Exception:");
      System.err.println(exception.getMessage());
      if (statement != null)
        System.err.println("Statement: " + statement.toString());
      System.err.println("ANSI-92 SQL State: " + exception.getSQLState());
      System.err.println("Vendor Error Code: " + exception.getErrorCode());
      exception.printStackTrace();
      exception = exception.getNextException();
    } while (exception != null);

    try {
      if (statement != null) {
        statement.close();
      }
      if (database != null) {
        database.close();
      }
    } catch (SQLException ex) {
      System.err.println("Error closing statement or database in ExceptionHandler.handleSQLException");
      handleSQLException(ex);
    }
    throw new RuntimeException(except);
  }
}
