package edu.georgetown.gucs.utility;

/**
 * Creates an ordered pair
 * 
 * @author Mark Maloof
 * 
 * @param <A>
 *          the type of the first object in this pair
 * @param <B>
 *          the type of the second object in this pair
 */
public class Pair<A, B> extends Object {

  private A a;
  private B b;

  /**
   * Constructor that sets the both objects in this pair
   * 
   * @param a
   *          the A object to set as the first object of this pair
   * @param b
   *          the B object to set as the second object of this pair
   */
  public Pair(A a, B b) {
    setA(a);
    setB(b);
  }

  /**
   * Sets the both objects in this pair
   * 
   * @param a
   *          the first object of this pair
   * @param b
   *          the second object of this pair
   */
  public void set(A a, B b) {
    setA(a);
    setB(b);
  }

  /**
   * Sets the first object in this pair
   * 
   * @param a
   *          the first object of this pair
   */
  public void setA(A a) {
    this.a = a;
  }

  /**
   * Sets the second object in this pair
   * 
   * @param b
   *          the second object of this pair
   */
  public void setB(B b) {
    this.b = b;
  }

  /**
   * Provides the first object in this pair
   * 
   * @return the first object in this pair
   */
  public A getA() {
    return a;
  }

  /**
   * Provides the second object in this pair
   * 
   * @return the second object in this pair
   */
  public B getB() {
    return b;
  }

  /**
   * Provides a string representation of the pair in the form (a, b)
   */
  public String toString() {
    return ("(" + a + ", " + b + ")");
  }
}
