package edu.georgetown.gucs.utility;

import java.sql.Time;

/**
 * Prints progress information, including elapsed time and status message
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class ProgressMeter {

  private long start;

  /**
   * Constructor that sets current time for later comparisons for elapsed time
   */
  public ProgressMeter() {
    start = System.nanoTime();
  }

  /**
   * Prints the status message and the current time for starting this progressMeter
   * 
   * @param message
   *          the string message to display for starting activity
   */
  public void start(String message) {
    start = System.nanoTime();
    System.out.println("Starting at: " + (new Time(System.currentTimeMillis())).toString());
    update(message);
  }

  /**
   * Prints the status message and time elapsed since starting this progressMeter
   * 
   * @param message
   *          the string message to display for this update
   */
  public void update(String message) {
    int elapsedSeconds = (int) ((System.nanoTime() - start) / Math.pow(10, 9));

    int hours = (int) elapsedSeconds / 3600;
    int minutes = (int) (elapsedSeconds - (hours * 3600)) / 60;
    int seconds = (int) (elapsedSeconds - (hours * 3600) - (minutes * 60));

    System.out.format("%02d:%02d:%02d     %s", hours, minutes, seconds, message);
    System.out.println();
  }

  /**
   * Prints the status message, time elapsed since starting this progressMeter, and the current time for stopping this
   * progressMeter
   * 
   * @param message
   *          the string message to display for ending activity
   */
  public void stop(String message) {
    update(message);
    System.out.println("Finishing at: " + (new Time(System.currentTimeMillis())).toString());
  }
}
